@@ -43,8 +43,8 @@ from barman.infofile import BackupInfo, WalFileInfo
 from barman.lockfile import ServerBackupSyncLock
 from barman.recovery_executor import RecoveryExecutor
 from barman.remote_status import RemoteStatusMixin
-from barman.utils import (fsync_dir, fsync_file, human_readable_timedelta,
-                          pretty_size)
+from barman.utils import (force_str, fsync_dir, fsync_file,
+                          human_readable_timedelta, pretty_size)
 
 _logger = logging.getLogger(__name__)
 
@@ -73,7 +73,7 @@ class BackupManager(RemoteStatusMixin):
                 self.executor = RsyncBackupExecutor(self)
         except SshCommandException as e:
             self.config.disabled = True
-            self.config.msg_list.append(str(e).strip())
+            self.config.msg_list.append(force_str(e).strip())
 
     @property
     def mode(self):
@@ -418,7 +418,7 @@ class BackupManager(RemoteStatusMixin):
         # Use BaseException instead of Exception to catch events like
         # KeyboardInterrupt (e.g.: CTRL-C)
         except BaseException as e:
-            msg_lines = str(e).strip().splitlines()
+            msg_lines = force_str(e).strip().splitlines()
             if backup_info:
                 # Use only the first line of exception message
                 # in backup_info error field
@@ -1067,13 +1067,12 @@ class BackupManager(RemoteStatusMixin):
 
         # Check the intersection between the required WALs and the archived
         # ones. They should all exist
-        bound_end = min(last_archived_wal, end_wal)
-        segments = xlog.generate_segment_names(
-            begin_wal,
-            bound_end,
-            xlog_segment_size=backup_info.xlog_segment_size)
+        segments = backup_info.get_required_wal_segments()
         missing_wal = None
         for wal in segments:
+            # Stop checking if we reach the last archived wal
+            if wal > last_archived_wal:
+                break
             wal_full_path = self.server.get_wal_full_path(wal)
             if not os.path.exists(wal_full_path):
                 missing_wal = wal
