@@ -37,7 +37,7 @@ from barman.exceptions import BadXlogSegmentName, RecoveryException, SyncError
 from barman.infofile import BackupInfo
 from barman.server import Server
 from barman.utils import (BarmanEncoder, configure_logging, drop_privileges,
-                          parse_log_level)
+                          force_str, parse_log_level)
 
 _logger = logging.getLogger(__name__)
 
@@ -141,7 +141,16 @@ def cron():
         # server is None and to report inactive and disabled servers,
         # but here we have only active and well configured servers.
 
-        server.cron()
+        try:
+            server.cron()
+        except Exception:
+            # A cron should never raise an exception, so this code
+            # should never be executed. However, it is here to protect
+            # unrelated servers in case of unexpected failures.
+            output.exception(
+                "Unable to run cron on server '%s', "
+                "please look in the barman log file for more details.",
+                name)
 
     output.close_and_exit()
 
@@ -521,7 +530,7 @@ def recover(args):
                            target_action=getattr(args, 'target_action', None),
                            standby_mode=getattr(args, 'standby_mode', None))
         except RecoveryException as exc:
-            output.error(str(exc))
+            output.error(force_str(exc))
 
     output.close_and_exit()
 
@@ -784,7 +793,7 @@ def list_files(args):
             "invalid xlog segment name %r\n"
             "HINT: Please run \"barman rebuild-xlogdb %s\" "
             "to solve this issue",
-            str(e), server.config.name)
+            force_str(e), server.config.name)
         output.close_and_exit()
 
 
